Crate sorted_ifyer

Functions

is_sorted
Returns true if potentialy_sorted_stuff is sorted bahavour with NaN or negative 0 or infinity is not defined Maximum is the highest number to sort, usefull in bubblesort Maximum must not be higher than potentialy_sorted_stuff.len() Recursiveness is how inefficent it is with 0 being the most efficent. Inefficency increases ((recursiveness)*2) once recursiveness >=1 asumming all other variables are the same